@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -54,10 +54,36 @@ class CmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CopyProject(self, request):
+        """复制一个项目，包括项目素材及轨道数据。目前仅普通剪辑及模板制作项目可复制，其它类型的项目不支持复制。
+
+        :param request: Request instance for CopyProject.
+        :type request: :class:`tencentcloud.cme.v20191029.models.CopyProjectRequest`
+        :rtype: :class:`tencentcloud.cme.v20191029.models.CopyProjectResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CopyProject", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CopyProjectResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateClass(self, request):
-        """新增分类，用于管理素材。
-        <li>分类层数不能超过10；</li>
-        <li>子分类数不能超过10。</li>
+        """新增分类，用于管理素材。分类层数不能超过20。
 
         :param request: Request instance for CreateClass.
         :type request: :class:`tencentcloud.cme.v20191029.models.CreateClassRequest`
@@ -113,7 +139,9 @@ class CmeClient(AbstractClient):
 
 
     def CreateProject(self, request):
-        """创建云剪的编辑项目，支持创建视频剪辑、直播剪辑、导播台项目以及视频拆条项目。
+        """创建云剪的编辑项目，支持创建视频剪辑、直播剪辑、导播台、视频拆条、录制回放以及云转推项目。
+
+        <b>若需使用云转推功能，请先咨询 [智能客服](https://cloud.tencent.com/act/event/smarty-service?from=doc_1138) 或 [提交工单](https://console.cloud.tencent.com/workorder/category) 。</b>
 
         :param request: Request instance for CreateProject.
         :type request: :class:`tencentcloud.cme.v20191029.models.CreateProjectRequest`
@@ -340,6 +368,34 @@ class CmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAccounts(self, request):
+        """获取用户账号信息。
+
+        :param request: Request instance for DescribeAccounts.
+        :type request: :class:`tencentcloud.cme.v20191029.models.DescribeAccountsRequest`
+        :rtype: :class:`tencentcloud.cme.v20191029.models.DescribeAccountsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAccounts", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAccountsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeClass(self, request):
         """获取指定归属者下所有的分类信息。
 
@@ -708,6 +764,34 @@ class CmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ExportVideoByTemplate(self, request):
+        """使用视频编辑模板直接导出视频。
+
+        :param request: Request instance for ExportVideoByTemplate.
+        :type request: :class:`tencentcloud.cme.v20191029.models.ExportVideoByTemplateRequest`
+        :rtype: :class:`tencentcloud.cme.v20191029.models.ExportVideoByTemplateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ExportVideoByTemplate", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ExportVideoByTemplateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ExportVideoByVideoSegmentationData(self, request):
         """使用视频智能拆条数据导出视频，将指定的视频拆条片段导出为一个视频。
 
@@ -850,6 +934,48 @@ class CmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def HandleStreamConnectProject(self, request):
+        """对云转推项目进行操作。
+        ### 操作类型<a id="Operation"></a>
+        - `AddInput`（添加输入源），包括：
+        	- 添加直播拉流输入源，参见 [示例1](#.E7.A4.BA.E4.BE.8B1-.E6.B7.BB.E5.8A.A0.E7.9B.B4.E6.92.AD.E6.8B.89.E6.B5.81.E8.BE.93.E5.85.A5.E6.BA.90)；
+        	- 添加直播推流输入源，参见 [示例2](#.E7.A4.BA.E4.BE.8B2-.E6.B7.BB.E5.8A.A0.E7.9B.B4.E6.92.AD.E6.8E.A8.E6.B5.81.E8.BE.93.E5.85.A5.E6.BA.90)；
+        	- 添加点播拉流输入源，参见 [示例3](#.E7.A4.BA.E4.BE.8B3-.E6.B7.BB.E5.8A.A0.E7.82.B9.E6.92.AD.E6.8B.89.E6.B5.81.E8.BE.93.E5.85.A5.E6.BA.90.E4.B8.94.E5.BE.AA.E7.8E.AF.E6.92.AD.E6.94.BE)、[示例4](#.E7.A4.BA.E4.BE.8B4-.E6.B7.BB.E5.8A.A0.E7.82.B9.E6.92.AD.E6.8B.89.E6.B5.81.E8.BE.93.E5.85.A5.E6.BA.90.E4.B8.94.E5.8D.95.E6.AC.A1.E6.92.AD.E6.94.BE)；
+        - `DeleteInput`（删除输入源），参见 [示例5](#.E7.A4.BA.E4.BE.8B5-.E5.88.A0.E9.99.A4.E8.BE.93.E5.85.A5.E6.BA.90)；
+        - `ModifyInput`（修改输入源），参见 [示例6](#.E7.A4.BA.E4.BE.8B6-.E4.BF.AE.E6.94.B9.E8.BE.93.E5.85.A5.E6.BA.90)；
+        - `AddOutput`（ 添加输出源），参见 [示例7](#.E7.A4.BA.E4.BE.8B7-.E6.B7.BB.E5.8A.A0.E8.BE.93.E5.87.BA.E6.BA.90)；
+        - `DeleteOutput`（删除输出源），参见 [示例8](#.E7.A4.BA.E4.BE.8B8-.E5.88.A0.E9.99.A4.E8.BE.93.E5.87.BA.E6.BA.90)；
+        - `ModifyOutput`（修改输出源），参见 [示例9](#.E7.A4.BA.E4.BE.8B9-.E4.BF.AE.E6.94.B9.E8.BE.93.E5.87.BA.E6.BA.90)；
+        - `Start`（开启转推），参见 [示例10](#.E7.A4.BA.E4.BE.8B10-.E5.BC.80.E5.90.AF.E4.BA.91.E8.BD.AC.E6.8E.A8)；
+        - `Stop`（停止转推），参见 [示例11](#.E7.A4.BA.E4.BE.8B11-.E5.81.9C.E6.AD.A2.E4.BA.91.E8.BD.AC.E6.8E.A8)；
+        - `SwitchInput`（切换输入源），参见 [示例12](#.E7.A4.BA.E4.BE.8B12-.E5.88.87.E6.8D.A2.E8.BE.93.E5.85.A5.E6.BA.90)；
+        - `ModifyCurrentStopTime`（修改当前计划结束时间），参见 [示例13](#.E7.A4.BA.E4.BE.8B13-.E4.BF.AE.E6.94.B9.E8.BD.AC.E6.8E.A8.E7.BB.93.E6.9D.9F.E6.97.B6.E9.97.B4)。
+
+        :param request: Request instance for HandleStreamConnectProject.
+        :type request: :class:`tencentcloud.cme.v20191029.models.HandleStreamConnectProjectRequest`
+        :rtype: :class:`tencentcloud.cme.v20191029.models.HandleStreamConnectProjectResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("HandleStreamConnectProject", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.HandleStreamConnectProjectResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ImportMaterial(self, request):
         """将云点播媒资文件导入到云剪媒体资源库。
 
@@ -1111,6 +1237,34 @@ class CmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ParseEvent(self, request):
+        """该接口接受制作云回调给客户的事件内容，将其转化为对应的 EventContent 结构，请不要实际调用该接口，只需要将接收到的事件内容直接使用 JSON 解析到 EventContent  即可使用。
+
+        :param request: Request instance for ParseEvent.
+        :type request: :class:`tencentcloud.cme.v20191029.models.ParseEventRequest`
+        :rtype: :class:`tencentcloud.cme.v20191029.models.ParseEventResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ParseEvent", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ParseEventResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RevokeResourceAuthorization(self, request):
         """资源所属实体对目标实体回收目标资源的相应权限，若原本没有相应权限则不产生变更。
 
